==> jc-1.4.0.tar.gz: java/security/cert/CertStoreSpi.h <==
// public abstract class java.security.cert.CertStoreSpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ef1da2cce024fd8d java_security_cert_CertStoreSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CertStoreSpi_H_
#define _JC_java_security_cert_CertStoreSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_cert_CRLSelector$object;
struct _jc_java_security_cert_CertSelector$object;
struct _jc_java_security_cert_CertStoreParameters$object;
struct _jc_java_util_Collection$object;

// Typedefs
typedef struct _jc_java_security_cert_CertStoreSpi$sub_refs	_jc_java_security_cert_CertStoreSpi$sub_refs;
typedef struct _jc_java_security_cert_CertStoreSpi$sub_nonrefs	_jc_java_security_cert_CertStoreSpi$sub_nonrefs;
typedef struct _jc_java_security_cert_CertStoreSpi$refs	_jc_java_security_cert_CertStoreSpi$refs;
typedef struct _jc_java_security_cert_CertStoreSpi$nonrefs	_jc_java_security_cert_CertStoreSpi$nonrefs;
typedef struct _jc_java_security_cert_CertStoreSpi$object	_jc_java_security_cert_CertStoreSpi$object;

typedef const struct _jc_java_security_cert_CertStoreSpi$vmethods	_jc_java_security_cert_CertStoreSpi$vmethods;
typedef const struct _jc_java_security_cert_CertStoreSpi$vtable	_jc_java_security_cert_CertStoreSpi$vtable;
typedef const struct _jc_java_security_cert_CertStoreSpi$vtype	_jc_java_security_cert_CertStoreSpi$vtype;

// Constructors
extern void _jc_java_security_cert_CertStoreSpi$method$_init$5fa483d00d0d58c4(_jc_env *, struct _jc_java_security_cert_CertStoreSpi$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_security_cert_CertStoreSpi$method$engineGetCRLs$e3a5332aca694ad3(_jc_env *, struct _jc_java_security_cert_CertStoreSpi$object *, struct _jc_object *);
extern struct _jc_object *_jc_java_security_cert_CertStoreSpi$method$engineGetCertificates$6e8d101a752c150d(_jc_env *, struct _jc_java_security_cert_CertStoreSpi$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CertStoreSpi$method_info$engineGetCRLs$e3a5332aca694ad3;
extern _jc_method _jc_java_security_cert_CertStoreSpi$method_info$engineGetCertificates$6e8d101a752c150d;

// Virtual methods structure
struct _jc_java_security_cert_CertStoreSpi$vmethods {
	struct _jc_object	*(*engineGetCRLs$e3a5332aca694ad3)(_jc_env *, struct _jc_java_security_cert_CertStoreSpi$object *, struct _jc_object *);
	struct _jc_object	*(*engineGetCertificates$6e8d101a752c150d)(_jc_env *, struct _jc_java_security_cert_CertStoreSpi$object *, struct _jc_object *);
};

// Vtable
struct _jc_java_security_cert_CertStoreSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertStoreSpi$vmethods	java_security_cert_CertStoreSpi;
};

// Vtype
struct _jc_java_security_cert_CertStoreSpi$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertStoreSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertStoreSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertStoreSpi$refs {
    _jc_java_security_cert_CertStoreSpi$sub_refs	java_security_cert_CertStoreSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertStoreSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertStoreSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertStoreSpi$sub_nonrefs	java_security_cert_CertStoreSpi;
};

// Object instance structure
struct _jc_java_security_cert_CertStoreSpi$object {
	_jc_java_security_cert_CertStoreSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertStoreSpi$vtype	*vtype;
	_jc_java_security_cert_CertStoreSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertStoreSpi$vtype _jc_java_security_cert_CertStoreSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertStoreSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertStoreSpi$class_object;

#endif	/* _JC_java_security_cert_CertStoreSpi_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/CertStoreSpi.h <==
// public abstract class java.security.cert.CertStoreSpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ef1da2cce024fd8d java_security_cert_CertStoreSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CertStoreSpi_H_
#define _JC_java_security_cert_CertStoreSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_cert_CRLSelector$object;
struct _jc_java_security_cert_CertSelector$object;
struct _jc_java_security_cert_CertStoreParameters$object;
struct _jc_java_util_Collection$object;

// Typedefs
typedef struct _jc_java_security_cert_CertStoreSpi$sub_refs	_jc_java_security_cert_CertStoreSpi$sub_refs;
typedef struct _jc_java_security_cert_CertStoreSpi$sub_nonrefs	_jc_java_security_cert_CertStoreSpi$sub_nonrefs;
typedef struct _jc_java_security_cert_CertStoreSpi$refs	_jc_java_security_cert_CertStoreSpi$refs;
typedef struct _jc_java_security_cert_CertStoreSpi$nonrefs	_jc_java_security_cert_CertStoreSpi$nonrefs;
typedef struct _jc_java_security_cert_CertStoreSpi$object	_jc_java_security_cert_CertStoreSpi$object;

typedef const struct _jc_java_security_cert_CertStoreSpi$vmethods	_jc_java_security_cert_CertStoreSpi$vmethods;
typedef const struct _jc_java_security_cert_CertStoreSpi$vtable	_jc_java_security_cert_CertStoreSpi$vtable;
typedef const struct _jc_java_security_cert_CertStoreSpi$vtype	_jc_java_security_cert_CertStoreSpi$vtype;

// Constructors
extern void _jc_java_security_cert_CertStoreSpi$method$_init$5fa483d00d0d58c4(_jc_env *, struct _jc_java_security_cert_CertStoreSpi$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_security_cert_CertStoreSpi$method$engineGetCRLs$e3a5332aca694ad3(_jc_env *, struct _jc_java_security_cert_CertStoreSpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_cert_CertStoreSpi$method$engineGetCertificates$6e8d101a752c150d(_jc_env *, struct _jc_java_security_cert_CertStoreSpi$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CertStoreSpi$method_info$engineGetCRLs$e3a5332aca694ad3;
extern _jc_method _jc_java_security_cert_CertStoreSpi$method_info$engineGetCertificates$6e8d101a752c150d;

// Virtual methods structure
struct _jc_java_security_cert_CertStoreSpi$vmethods {
	struct _jc_object	*(*engineGetCRLs$e3a5332aca694ad3)(_jc_env *, struct _jc_java_security_cert_CertStoreSpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineGetCertificates$6e8d101a752c150d)(_jc_env *, struct _jc_java_security_cert_CertStoreSpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_CertStoreSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertStoreSpi$vmethods	java_security_cert_CertStoreSpi;
};

// Vtype
struct _jc_java_security_cert_CertStoreSpi$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertStoreSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertStoreSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertStoreSpi$refs {
    _jc_java_security_cert_CertStoreSpi$sub_refs	java_security_cert_CertStoreSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertStoreSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertStoreSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertStoreSpi$sub_nonrefs	java_security_cert_CertStoreSpi;
};

// Object instance structure
struct _jc_java_security_cert_CertStoreSpi$object {
	_jc_java_security_cert_CertStoreSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertStoreSpi$vtype	*vtype;
	_jc_java_security_cert_CertStoreSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertStoreSpi$vtype _jc_java_security_cert_CertStoreSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertStoreSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertStoreSpi$class_object;

#endif	/* _JC_java_security_cert_CertStoreSpi_H_ */
